==> geoffwilliams-r_profile-1.9.0.tar.gz: geoffwilliams-r_profile-1.9.0/spec/classes/cloud/azure_spec.rb <==
require 'spec_helper'
require 'puppet_factset'
describe 'r_profile::cloud::azure' do
  # Uncomment only the factset you would like to use for these tests
  # system_name = 'AIX-6.1-powerpc'
  # system_name = 'AIX-7.1-powerpc'
  # system_name = 'CentOS-5.11-32'
  # system_name = 'CentOS-5.11-64'
  # system_name = 'CentOS-6.6-32'
  # system_name = 'CentOS-6.6-64'
  system_name = 'CentOS-7.0-64'
  # system_name = 'CentOS-7.3-64'
  # system_name = 'Debian-6.0.10-32'
  # system_name = 'Debian-6.0.10-64'
  # system_name = 'Debian-7.8-32'
  # system_name = 'Debian-7.8-64'
  # system_name = 'Debian-8.7-64'
  # system_name = 'SLES-11.3-64'
  # system_name = 'SLES-12.1-64'
  # system_name = 'Ubuntu-12.04-32'
  # system_name = 'Ubuntu-12.04-64'
  # system_name = 'Ubuntu-14.04-32'
  # system_name = 'Ubuntu-14.04-64'
  # system_name = 'Ubuntu-16.04-64'
  # system_name = 'Windows_Server-2008r2-64'
  # system_name = 'Windows_Server-2012r2-64'
  # system_name = 'solaris-10_u9-sparc-64'
  # system_name = 'solaris-11.2-sparc-64'
  let :facts do
    PuppetFactset::factset_hash(system_name)
  end

  let :params do
    {
      :subscription_id => 'the_subscription_id',
      :tenant_id       => 'the_tenant_id',
      :client_id       => 'the_client_id',
      :client_secret   => 'the_client_secret',
      :azure_vm        => {
        'mycoolvm' => {
          'ensure'         => 'present',
          'location'       => 'centralus',
          'image'          => 'canonical:ubuntuserver:14.04.2-LTS:latest',
          'user'           => 'azureuser',
          'password'       => 'Password_!',
          'size'           => 'Standard_A0',
          'resource_group' => 'puppetvms',
        }
      }
    }
  end

  context 'compiles ok' do
    it { should compile }
  end

  context 'with default values for all parameters' do
    it { should contain_class('r_profile::cloud::azure') }
  end
end

==> geoffwilliams-r_profile-1.12.1.tar.gz: geoffwilliams-r_profile-1.12.1/spec/classes/cloud/azure_spec.rb <==
require 'spec_helper'
require 'puppet_factset'
describe 'r_profile::cloud::azure' do
  # Uncomment only the factset you would like to use for these tests
  # system_name = 'AIX-6.1-powerpc'
  # system_name = 'AIX-7.1-powerpc'
  # system_name = 'CentOS-5.11-32'
  # system_name = 'CentOS-5.11-64'
  # system_name = 'CentOS-6.6-32'
  # system_name = 'CentOS-6.6-64'
  system_name = 'CentOS-7.0-64'
  # system_name = 'CentOS-7.3-64'
  # system_name = 'Debian-6.0.10-32'
  # system_name = 'Debian-6.0.10-64'
  # system_name = 'Debian-7.8-32'
  # system_name = 'Debian-7.8-64'
  # system_name = 'Debian-8.7-64'
  # system_name = 'SLES-11.3-64'
  # system_name = 'SLES-12.1-64'
  # system_name = 'Ubuntu-12.04-32'
  # system_name = 'Ubuntu-12.04-64'
  # system_name = 'Ubuntu-14.04-32'
  # system_name = 'Ubuntu-14.04-64'
  # system_name = 'Ubuntu-16.04-64'
  # system_name = 'Windows_Server-2008r2-64'
  # system_name = 'Windows_Server-2012r2-64'
  # system_name = 'solaris-10_u9-sparc-64'
  # system_name = 'solaris-11.2-sparc-64'
  let :facts do
    PuppetFactset::factset_hash(system_name)
  end

  # let :trusted do
  #   {
  #     :certname => "sandpit",
  #   }
  # end

  let :params do
    {
      :subscriptions => {
        "sandpit" => {
          "subscription_id"    => 'sp the_subscription_id',
          "user"               => 'azure_sandpit',
          "tenant_id"          => 'sp the_tenant_id',
          "client_id"          => 'sp the_client_id',
          "client_secret"      => 'sp the_client_secret',
          "puppet_master_fqdn" => "sp_puppet.megacorp.com",
        },
        "production" => {
          "subscription_id"    => 'pr the_subscription_id',
          "user"               => 'azure_prod',
          "tenant_id"          => 'pr the_tenant_id',
          "client_id"          => 'pr the_client_id',
          "client_secret"      => 'pr the_client_secret',
          "puppet_master_fqdn" => "pr.puppet.megacorp.com",
        },
      },
      :azure_vm => {
        'mycoolvm' => {
          'ensure'         => 'present',
          'location'       => 'centralus',
          'image'          => 'canonical:ubuntuserver:14.04.2-LTS:latest',
          'user'           => 'azureuser',
          'password'       => 'Password_!',
          'size'           => 'Standard_A0',
          'resource_group' => 'puppetvms',
        }
      }
    }
  end

  context 'compiles ok' do
    it { should compile }
  end

  context 'with default values for all parameters' do
    it { should contain_class('r_profile::cloud::azure') }
  end
end
